@@ -146,3 +146,77 @@ fmt <- function(){
   function(x) format(x,nsmall = 3,scientific = FALSE)
 }
 
+
+#' @title effectSizeCI
+#' @description 95% Confidence Intervals (CI) on Standardised Effect Sizes (d) for cross-over repeated-measures designs
+#' The procedure is based on finding the upper and lower 0.025 bounds for the related t-variable.
+#' The upper and lower bounds on the t-variable are then used to calculate to upper and lower bounds on the
+#' repeated measures effect size (d_RM) by multiplying the upper and lower bound of the t-variable by sqrt((n1+n2)/(2*(n1*n2))).
+#' Upper and lower bounds on the equivalent independent groups effect size (d_IG) are found by multiplying the upper and lower
+#' bounds on d_RM by sqrt(1-r).
+#' @author Lech Madeyski and Barbara Kitchenham
+#' @export effectSizeCI
+#' @param epsilon The precision used to caculate the probability that a value from the non-central t distribution is less than t_LB etc.
+#' @param maxsteps The maximum number of steps of the iterative procedure (the procedure terminates at maxsteps or earlier if enough CI with enough precision have been calculated)
+#' @param stepsize The size of steps (influences the convergence of the calculations, i.e., the number of steps required to obtain the final result of precison defined by the epsilon)
+#' @param t t-statistics
+#' @param n1 The number of observations in sequence group 1
+#' @param n2 The number of observations in sequence group 2
+#' @param r The correlation between outcomes for individual subject (the within subject correlation)
+#' @return A list of Confidence Intervals for: t-statistic (t_LB and t_UB), repeted-measures effect size d_RM (d_RM_LB, d_RM_UB), independent groups effect size (d_IG_LB, d_IG_UB)
+#' @examples
+#' effectSizeCI(t=14.4, n1=15, n2=15, r=0.6401)
+effectSizeCI <- function(epsilon=0.0000000001, maxsteps=100, stepsize=3, t, n1, n2, r)
+{
+  stepsize=3 #influences the number of steps required to obtain the final result (i.e., the result of precison defined by the epsilon), e.g., consider stepsize=2
+  df=n1+n2-2
+  d_RM=t*sqrt((n1+n2)/(2*n1*n2))
+  c=1-3/(4*df-1)
+  vart=(df/(df-2))*(1+t^2)-t^2/c^2
+
+
+  #t_LB <- vector(length = maxsteps)
+  i <- 1
+  t_LB <- t-2*sqrt(vart)
+  pt_LB <- stats::pt(t_LB, df=28, ncp=t)
+  t_UB <- t+2*sqrt(vart)
+  pt_UB <- stats::pt(t_UB, df=28, ncp=t)
+  while( i <= maxsteps & (pt_LB >= (0.025+epsilon) |  pt_LB <= (0.025-epsilon) | pt_UB >= (0.975+epsilon) | pt_UB <= (0.975-epsilon)) )
+  {
+    if(i==1)
+    {
+      t_LB <- (t+t_LB)/2
+      t_UB <- (t+t_UB)/2
+    }
+    else
+    {
+      if(pt_LB <= (0.025-epsilon)) # we need larger value of t_LB
+      {
+        t_LB <- (1+(stepsize*abs(pt_LB-0.025))) * t_LB
+      }
+      if(pt_LB >= (0.025+epsilon))  # we need smaler value of t_LB
+      {
+        t_LB <- (1-(stepsize*abs(pt_LB-0.025))) * t_LB
+      }
+
+      if(pt_UB <= (0.975-epsilon)) # we need larger value of t_UB
+      {
+        t_UB <- (1+(stepsize*abs(pt_UB-0.975))) * t_UB
+      }
+      if(pt_UB >= (0.975+epsilon))  # we need smaler value of t_LB
+      {
+        t_UB <- (1-(stepsize*abs(pt_UB-0.975))) * t_UB
+      }
+
+    }
+    pt_LB <- stats::pt(t_LB, df=28, ncp=t)
+    pt_UB <- stats::pt(t_UB, df=28, ncp=t)
+    i <- i + 1
+  }
+  d_RM_LB <- t_LB*sqrt((n1+n2)/(2*n1*n2))
+  d_RM_UB <- t_UB*sqrt((n1+n2)/(2*n1*n2))
+  d_IG_LB <- d_RM_LB*sqrt(1-r)
+  d_IG_UB <- d_RM_UB*sqrt(1-r)
+  result <- list(t_LB=t_LB, t_UB=t_UB, d_RM_LB=d_RM_LB, d_RM_UB=d_RM_UB, d_IG_LB=d_IG_LB, d_IG_UB=d_IG_UB)
+  return(result) #t=14.4, n1=15, n2=15, r=0.6401, t_LB=10.967807, d_RM_LB=2.831876, t_UB=19.98904, d_RM_UB=5.161148, d_IG_LB=1.698889, d_IG_UB=3.096259
+}
